@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -33,7 +33,7 @@ class HeaderViewMenuHandler: public QObject
 {
     Q_OBJECT
 public:
-    HeaderViewMenuHandler(QHeaderView* parent);
+    explicit HeaderViewMenuHandler(QHeaderView* parent);
 private slots:
     void headerMenuRequested(QPoint);
     void headerMenuActionToggled(QAction*);
