@@ -1,14 +1,14 @@
 /* ****************************************************************************
   This file is part of Lokalize
 
-  Copyright (C) 2008 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2008-2014 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or
   modify it under the terms of the GNU General Public License as
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -27,24 +27,28 @@
 #include "pos.h"
 
 #include <kxmlguiwindow.h>
-#include <kurl.h>
 #include <kconfiggroup.h>
 
 #include <QPointer>
 #include <QMap>
+#include <QUrl>
+#include <QMdiArea>
 #include <QDBusObjectPath>
 
-
+class QLabel;
 class QMdiSubWindow;
 class QMdiArea;
 class QActionGroup;
-class KAction;
+class LokalizeMdiArea;
 class KRecentFilesAction;
 class EditorTab;
 class MultiEditorAdaptor;
 class ProjectScriptingPlugin;
-namespace TM {class TMTab;}
 class FileSearchTab;
+namespace TM
+{
+class TMTab;
+}
 
 /**
  * @short Lokalize MDI (tabbed) window.
@@ -65,13 +69,13 @@ class LokalizeMainWindow: public KXmlGuiWindow
 
 public:
     LokalizeMainWindow();
-    ~LokalizeMainWindow();
+    ~LokalizeMainWindow() override;
 
 protected:
     void saveProjectState(KConfigGroup&);
-    void saveProperties(KConfigGroup& stateGroup);
-    bool queryClose();
-    void readProperties(const KConfigGroup& stateGroup);
+    void saveProperties(KConfigGroup& stateGroup) override;
+    bool queryClose() override;
+    void readProperties(const KConfigGroup& stateGroup) override;
     void registerDBusAdaptor();
     void setupActions();
 
@@ -86,8 +90,14 @@ private slots:
     void editorClosed(QObject* obj);
     void resetMultiEditorAdaptor();
 
-    void openProject(const KUrl& url){openProject(url.path());}//convenience overload for recent projects action
-    void openProject(){openProject(QString());}
+    void openProject(const QUrl& url)
+    {
+        openProject(url.toLocalFile());   //convenience overload for recent projects action
+    }
+    void openProject()
+    {
+        openProject(QString());
+    }
 
 
 public slots:
@@ -109,7 +119,7 @@ public slots:
 
     /// @returns 0 if current tab is not of Editor type
     Q_SCRIPTABLE QObject* activeEditor();
-    
+
     /// @returns editor with @param path loaded or 0 if there is no such editor.
     Q_SCRIPTABLE QObject* editorForFile(const QString& path);
     /**
@@ -128,11 +138,16 @@ public slots:
     //Q_SCRIPTABLE void processEvents();
 
     //returns 0 if error
-    EditorTab* fileOpen(KUrl url=KUrl(),int entry=0, bool setAsActive=true, const QString& mergeFile=QString(), bool silent=false);
-    EditorTab* fileOpen(const KUrl& url, const QString& source, const QString& ctxt);
-    EditorTab* fileOpen(const KUrl& url, DocPosition docPos, int selection);
+    EditorTab* fileOpen_(QString url, const bool setAsActive);
+    EditorTab* fileOpen(QString url = QString(), int entry = 0, bool setAsActive = true, const QString& mergeFile = QString(), bool silent = false);
+    EditorTab* fileOpen(const QString& url, const QString& source, const QString& ctxt, const bool setAsActive);
+    EditorTab* fileOpen(const QString& url, DocPosition docPos, int selection, const bool setAsActive);
+    EditorTab* fileOpen(const QUrl& url)
+    {
+        return fileOpen(url.toLocalFile(), 0, true);
+    }
     TM::TMTab* showTM();
-    FileSearchTab* showFileSearch(bool activate=true);
+    FileSearchTab* showFileSearch(bool activate = true);
     void fileSearchNext();
     void addFilesToSearch(const QStringList&);
 
@@ -142,7 +157,7 @@ signals:
     Q_SCRIPTABLE void editorActivated();
 
 private:
-    QMdiArea* m_mdiArea;
+    LokalizeMdiArea* m_mdiArea;
     QPointer<QMdiSubWindow> m_prevSubWindow;
     QPointer<QMdiSubWindow> m_projectSubWindow;
     QPointer<QMdiSubWindow> m_translationMemorySubWindow;
@@ -153,6 +168,7 @@ private:
     QActionGroup* m_managerActions;
     KRecentFilesAction* m_openRecentFileAction;
     KRecentFilesAction* m_openRecentProjectAction;
+    QVector<QLabel*> m_statusBarLabels;
 
     QByteArray m_lastEditorState;
 
@@ -162,21 +178,28 @@ private:
     ProjectScriptingPlugin* m_projectScriptingPlugin;
 
     //using QPointer switches it.value() to 0 before we get to destroyed() handler
-    //typedef QMap<KUrl, QPointer<QMdiSubWindow> > FileToEditor;
-    typedef QMap<KUrl, QMdiSubWindow*> FileToEditor;
+    //typedef QMap<QUrl, QPointer<QMdiSubWindow> > FileToEditor;
+    typedef QMap<QString, QMdiSubWindow*> FileToEditor;
     FileToEditor m_fileToEditor;
 };
 
+class LokalizeMdiArea: public QMdiArea
+{
+    Q_OBJECT
+public slots:
+    void activateNextSubWindow();
+    void activatePreviousSubWindow();
+};
 
 #include <kross/ui/plugin.h>
 
 class ProjectScriptingPlugin: public Kross::ScriptingPlugin
 {
-Q_OBJECT
+    Q_OBJECT
 public:
     ProjectScriptingPlugin(QObject* lokalize, QObject* editor);
     ~ProjectScriptingPlugin();
-    void setDOMDocument (const QDomDocument &document, bool merge = false);
+    void setDOMDocument(const QDomDocument &document, bool merge = false) override;
 
 private slots:
     void doAutoruns();
@@ -185,15 +208,15 @@ private slots:
 
 class DelayedFileOpener: public QObject
 {
-Q_OBJECT
+    Q_OBJECT
 public:
-    DelayedFileOpener(const KUrl::List& urls, LokalizeMainWindow* lmw);
+    DelayedFileOpener(const QVector<QString>& urls, LokalizeMainWindow* lmw);
 
 private slots:
     void doOpen();
 
 private:
-    KUrl::List m_urls;
+    QVector<QString> m_urls;
     LokalizeMainWindow* m_lmw;
 };
 
