@@ -8,7 +8,7 @@
   published by the Free Software Foundation; either version 2 of
   the License or (at your option) version 3 or any later version
   accepted by the membership of KDE e.V. (or its successor approved
-  by the membership of KDE e.V.), which shall act as a proxy 
+  by the membership of KDE e.V.), which shall act as a proxy
   defined in Section 14 of version 3 of the license.
 
   This program is distributed in the hope that it will be useful,
@@ -25,49 +25,45 @@
 #define HIGHLIGHTER_H
 
 #include <QSyntaxHighlighter>
-#ifndef NOKDE
 #include <sonnet/highlighter.h>
 #include <kcolorscheme.h>
-#elif defined(SONNET_STATIC)
-#include "highlighter.h"
-#endif
 
 #include <QHash>
 #include <QTextCharFormat>
-#include <QSyntaxHighlighter>
 
 
 class QTextDocument;
 class QTextEdit;
 
-#if !defined(NOKDE) || defined(SONNET_STATIC)
 class SyntaxHighlighter : public Sonnet::Highlighter
-#else
-class SyntaxHighlighter : public QSyntaxHighlighter
-#endif
 {
     Q_OBJECT
 
 public:
     explicit SyntaxHighlighter(QTextEdit *parent);
-    ~SyntaxHighlighter(){};
+    ~SyntaxHighlighter() override {}
 
-    void setApprovementState(bool a){m_approved=a;};
-    void setSourceString(const QString& s){m_sourceString=s;}
+    void setApprovementState(bool a)
+    {
+        m_approved = a;
+    }
+    void setSourceString(const QString& s)
+    {
+        m_sourceString = s;
+    }
 
 protected:
-    void highlightBlock(const QString &text);
+    void highlightBlock(const QString &text) override;
 
-    void setMisspelled(int start, int count);
-    void unsetMisspelled(int start, int count);
+    void setMisspelled(int start, int count) override;
+    void unsetMisspelled(int start, int count) override;
 
 private slots:
     void settingsChanged();
 
 //    void setFormatRetainingUnderlines(int start, int count, QTextCharFormat format);
 private:
-    struct HighlightingRule
-    {
+    struct HighlightingRule {
         QRegExp pattern;
         QTextCharFormat format;
     };
@@ -75,9 +71,7 @@ private:
 
 //     bool fromDocbook;
     QTextCharFormat tagFormat;
-#ifndef NOKDE
     KStatefulBrush tagBrush;
-#endif
     bool m_approved;
     QString m_sourceString;
 };
