@@ -31,6 +31,7 @@
 
 #include <QSqlQueryModel>
 #include <QSqlDatabase>
+#include <QMutex>
 
 class KXMLGUIClient;
 class QComboBox;
@@ -42,7 +43,8 @@ class QaView;
 class Ui_QueryOptions;
 class TMResultsSortFilterProxyModel;
 
-namespace TM {
+namespace TM
+{
 class TMDBModel;
 class ExecQueryJob;
 
@@ -56,18 +58,27 @@ class TMTab: public LokalizeSubwindowBase2
     //qdbuscpp2xml -m -s tm/tmtab.h -o tm/org.kde.lokalize.TranslationMemory.xml
 
 public:
-    TMTab(QWidget *parent);
-    ~TMTab();
+    explicit TMTab(QWidget *parent);
+    ~TMTab() override;
 
-    void hideDocks(){};
-    void showDocks(){};
-    KXMLGUIClient* guiClient(){return (KXMLGUIClient*)this;}
+    void hideDocks() override {}
+    void showDocks() override {}
+    KXMLGUIClient* guiClient() override
+    {
+        return (KXMLGUIClient*)this;
+    }
     QString dbusObjectPath();
-    int dbusId(){return m_dbusId;}
+    int dbusId()
+    {
+        return m_dbusId;
+    }
 
 
 public slots:
-    Q_SCRIPTABLE bool findGuiText(QString text){return findGuiTextPackage(text,QString());}
+    Q_SCRIPTABLE bool findGuiText(QString text)
+    {
+        return findGuiTextPackage(text, QString());
+    }
     Q_SCRIPTABLE bool findGuiTextPackage(QString text, QString package);
     Q_SCRIPTABLE void lookup(QString source, QString target);
     //void lookup(DocPosition::Part, QString text);
@@ -80,14 +91,15 @@ public slots:
     void openFile();
     void handleResults();
     void displayTotalResultCount();
-    void setQAMode(bool enabled=true);
+    void setQAMode();
+    void setQAMode(bool enabled);
 
 signals:
-    void fileOpenRequested(const QString& url, const QString& source, const QString& ctxt);
+    void fileOpenRequested(const QString& url, const QString& source, const QString& ctxt, const bool setAsActive);
 
 private:
-    void dragEnterEvent(QDragEnterEvent* event);
-    void dropEvent(QDropEvent*);
+    void dragEnterEvent(QDragEnterEvent* event) override;
+    void dropEvent(QDropEvent*) override;
 
 
 private:
@@ -106,9 +118,8 @@ class TMDBModel: public QSqlQueryModel
     Q_OBJECT
 public:
 
-    enum TMDBModelColumns
-    {
-        Source=0,
+    enum TMDBModelColumns {
+        Source = 0,
         Target,
         Context,
         Filepath,
@@ -119,32 +130,41 @@ public:
         ColumnCount
     };
 
-    enum QueryType
-    {
-        SubStr=0,
+    enum QueryType {
+        SubStr = 0,
         WordOrder,
         Glob
     };
 
-    enum Roles
-    {
-        FullPathRole=Qt::UserRole,
-        TransStateRole=Qt::UserRole+1,
+    enum Roles {
+        FullPathRole = Qt::UserRole,
+        TransStateRole = Qt::UserRole + 1,
         //HtmlDisplayRole=FastSizeHintItemDelegate::HtmlDisplayRole
     };
 
-    TMDBModel(QObject* parent);
-    ~TMDBModel(){}
+    explicit TMDBModel(QObject* parent);
+    ~TMDBModel() {}
 
-    QVariant data(const QModelIndex& item, int role=Qt::DisplayRole) const;
-    int columnCount(const QModelIndex& parent=QModelIndex()) const{Q_UNUSED(parent); return ColumnCount;}
-    int totalResultCount()const{return m_totalResultCount;}
+    QVariant data(const QModelIndex& item, int role = Qt::DisplayRole) const override;
+    int columnCount(const QModelIndex& parent = QModelIndex()) const override
+    {
+        Q_UNUSED(parent);
+        return ColumnCount;
+    }
+    int totalResultCount()const
+    {
+        return m_totalResultCount;
+    }
+    QString dbName()const
+    {
+        return m_dbName;
+    }
 
 public slots:
     void setFilter(const QString& source, const QString& target,
                    bool invertSource, bool invertTarget,
                    const QString& filemask
-                   );
+                  );
     void setQueryType(int);
     void setDB(const QString&);
     void slotQueryExecuted(ExecQueryJob*);
@@ -162,6 +182,8 @@ private:
     QueryType m_queryType;
     QString m_dbName;
     int m_totalResultCount;
+public:
+    mutable QMutex m_dbOperationMutex;
 };
 
 //const QString& sourceRefine, const QString& targetRefine
